@@ -5,6 +5,6 @@
 fn main() {
     println!("cargo:rerun-if-changed=build.rs");
     if cfg!(feature = "test-blas-openblas-sys") {
-        println!("cargo:rustc-link-lib={}=openblas", "dylib");
+        println!("cargo:rustc-link-lib=dylib=openblas");
     }
 }
