@@ -7,25 +7,18 @@
 // except according to those terms.
 
 use std::hash;
+use std::isize;
 use std::iter::FromIterator;
 use std::iter::IntoIterator;
 use std::mem;
-use std::ops::{
-    Index,
-    IndexMut,
-};
+use std::ops::{Index, IndexMut};
 
-use imp_prelude::*;
-use iter::{
-    Iter,
-    IterMut,
-};
-use {
-    NdIndex,
-};
+use crate::imp_prelude::*;
+use crate::iter::{Iter, IterMut};
+use crate::NdIndex;
 
-use numeric_util;
-use {Zip, FoldWhile};
+use crate::numeric_util;
+use crate::{FoldWhile, Zip};
 
 #[cold]
 #[inline(never)]
@@ -35,9 +28,10 @@ pub(crate) fn array_out_of_bounds() -> ! {
 
 #[inline(always)]
 pub fn debug_bounds_check<S, D, I>(_a: &ArrayBase<S, D>, _index: &I)
-    where D: Dimension,
-          I: NdIndex<D>,
-          S: Data,
+where
+    D: Dimension,
+    I: NdIndex<D>,
+    S: Data,
 {
     debug_bounds_check!(_a, *_index);
 }
@@ -46,17 +40,21 @@ pub fn debug_bounds_check<S, D, I>(_a: &ArrayBase<S, D>, _index: &I)
 ///
 /// **Panics** if index is out of bounds.
 impl<S, D, I> Index<I> for ArrayBase<S, D>
-    where D: Dimension,
-          I: NdIndex<D>,
-          S: Data,
+where
+    D: Dimension,
+    I: NdIndex<D>,
+    S: Data,
 {
     type Output = S::Elem;
     #[inline]
     fn index(&self, index: I) -> &S::Elem {
         debug_bounds_check!(self, index);
         unsafe {
-            &*self.ptr.offset(index.index_checked(&self.dim, &self.strides)
-                                   .unwrap_or_else(|| array_out_of_bounds()))
+            &*self.ptr.as_ptr().offset(
+                index
+                    .index_checked(&self.dim, &self.strides)
+                    .unwrap_or_else(|| array_out_of_bounds()),
+            )
         }
     }
 }
@@ -65,27 +63,32 @@ impl<S, D, I> Index<I> for ArrayBase<S, D>
 ///
 /// **Panics** if index is out of bounds.
 impl<S, D, I> IndexMut<I> for ArrayBase<S, D>
-    where D: Dimension,
-          I: NdIndex<D>,
-          S: DataMut,
+where
+    D: Dimension,
+    I: NdIndex<D>,
+    S: DataMut,
 {
     #[inline]
     fn index_mut(&mut self, index: I) -> &mut S::Elem {
         debug_bounds_check!(self, index);
         unsafe {
-            &mut *self.as_mut_ptr().offset(index.index_checked(&self.dim, &self.strides)
-                                                .unwrap_or_else(|| array_out_of_bounds()))
+            &mut *self.as_mut_ptr().offset(
+                index
+                    .index_checked(&self.dim, &self.strides)
+                    .unwrap_or_else(|| array_out_of_bounds()),
+            )
         }
     }
 }
 
 /// Return `true` if the array shapes and all elements of `self` and
 /// `rhs` are equal. Return `false` otherwise.
-impl<S, S2, D> PartialEq<ArrayBase<S2, D>> for ArrayBase<S, D>
-    where D: Dimension,
-          S: Data,
-          S2: Data<Elem = S::Elem>,
-          S::Elem: PartialEq
+impl<A, B, S, S2, D> PartialEq<ArrayBase<S2, D>> for ArrayBase<S, D>
+where
+    A: PartialEq<B>,
+    S: Data<Elem = A>,
+    S2: Data<Elem = B>,
+    D: Dimension,
 {
     fn eq(&self, rhs: &ArrayBase<S2, D>) -> bool {
         if self.shape() != rhs.shape() {
@@ -98,34 +101,77 @@ impl<S, S2, D> PartialEq<ArrayBase<S2, D>> for ArrayBase<S, D>
         }
         Zip::from(self)
             .and(rhs)
-            .fold_while(true, |_, a, b|
-            if a != b {
-                FoldWhile::Done(false)
-            } else {
-                FoldWhile::Continue(true)
-            }).into_inner()
+            .fold_while(true, |_, a, b| {
+                if a != b {
+                    FoldWhile::Done(false)
+                } else {
+                    FoldWhile::Continue(true)
+                }
+            })
+            .into_inner()
     }
 }
 
 impl<S, D> Eq for ArrayBase<S, D>
-    where D: Dimension,
-          S: Data,
-          S::Elem: Eq,
-{ }
+where
+    D: Dimension,
+    S: Data,
+    S::Elem: Eq,
+{
+}
+
+impl<A, S> From<Vec<A>> for ArrayBase<S, Ix1>
+where
+    S: DataOwned<Elem = A>,
+{
+    /// Create a one-dimensional array from a vector (no copying needed).
+    ///
+    /// **Panics** if the length is greater than `isize::MAX`.
+    ///
+    /// ```rust
+    /// use ndarray::Array;
+    ///
+    /// let array = Array::from(vec![1., 2., 3., 4.]);
+    /// ```
+    fn from(v: Vec<A>) -> Self {
+        if mem::size_of::<A>() == 0 {
+            assert!(
+                v.len() <= isize::MAX as usize,
+                "Length must fit in `isize`.",
+            );
+        }
+        unsafe { Self::from_shape_vec_unchecked(v.len() as Ix, v) }
+    }
+}
 
 impl<A, S> FromIterator<A> for ArrayBase<S, Ix1>
-    where S: DataOwned<Elem=A>
+where
+    S: DataOwned<Elem = A>,
 {
+    /// Create a one-dimensional array from an iterable.
+    ///
+    /// **Panics** if the length is greater than `isize::MAX`.
+    ///
+    /// ```rust
+    /// use ndarray::{Array, arr1};
+    /// use std::iter::FromIterator;
+    ///
+    /// // Either use `from_iter` directly or use `Iterator::collect`.
+    /// let array = Array::from_iter((0..5).map(|x| x * x));
+    /// assert!(array == arr1(&[0, 1, 4, 9, 16]))
+    /// ```
     fn from_iter<I>(iterable: I) -> ArrayBase<S, Ix1>
-        where I: IntoIterator<Item=A>,
+    where
+        I: IntoIterator<Item = A>,
     {
-        ArrayBase::from_iter(iterable)
+        Self::from(iterable.into_iter().collect::<Vec<A>>())
     }
 }
 
 impl<'a, S, D> IntoIterator for &'a ArrayBase<S, D>
-    where D: Dimension,
-          S: Data,
+where
+    D: Dimension,
+    S: Data,
 {
     type Item = &'a S::Elem;
     type IntoIter = Iter<'a, S::Elem, D>;
@@ -136,8 +182,9 @@ impl<'a, S, D> IntoIterator for &'a ArrayBase<S, D>
 }
 
 impl<'a, S, D> IntoIterator for &'a mut ArrayBase<S, D>
-    where D: Dimension,
-          S: DataMut
+where
+    D: Dimension,
+    S: DataMut,
 {
     type Item = &'a mut S::Elem;
     type IntoIter = IterMut<'a, S::Elem, D>;
@@ -148,7 +195,8 @@ impl<'a, S, D> IntoIterator for &'a mut ArrayBase<S, D>
 }
 
 impl<'a, A, D> IntoIterator for ArrayView<'a, A, D>
-    where D: Dimension
+where
+    D: Dimension,
 {
     type Item = &'a A;
     type IntoIter = Iter<'a, A, D>;
@@ -159,7 +207,8 @@ impl<'a, A, D> IntoIterator for ArrayView<'a, A, D>
 }
 
 impl<'a, A, D> IntoIterator for ArrayViewMut<'a, A, D>
-    where D: Dimension
+where
+    D: Dimension,
 {
     type Item = &'a mut A;
     type IntoIter = IterMut<'a, A, D>;
@@ -170,9 +219,10 @@ impl<'a, A, D> IntoIterator for ArrayViewMut<'a, A, D>
 }
 
 impl<'a, S, D> hash::Hash for ArrayBase<S, D>
-    where D: Dimension,
-          S: Data,
-          S::Elem: hash::Hash
+where
+    D: Dimension,
+    S: Data,
+    S::Elem: hash::Hash,
 {
     // Note: elements are hashed in the logical order
     fn hash<H: hash::Hasher>(&self, state: &mut H) {
@@ -200,28 +250,33 @@ impl<'a, S, D> hash::Hash for ArrayBase<S, D>
 
 /// `ArrayBase` is `Sync` when the storage type is.
 unsafe impl<S, D> Sync for ArrayBase<S, D>
-    where S: Sync + Data, D: Sync
-{ }
+where
+    S: Sync + Data,
+    D: Sync,
+{
+}
 
 /// `ArrayBase` is `Send` when the storage type is.
 unsafe impl<S, D> Send for ArrayBase<S, D>
-    where S: Send + Data, D: Send
-{ }
+where
+    S: Send + Data,
+    D: Send,
+{
+}
 
-#[cfg(any(feature = "rustc-serialize", feature = "serde"))]
+#[cfg(any(feature = "serde"))]
 // Use version number so we can add a packed format later.
 pub const ARRAY_FORMAT_VERSION: u8 = 1u8;
 
-
 // use "raw" form instead of type aliases here so that they show up in docs
 /// Implementation of `ArrayView::from(&S)` where `S` is a slice or slicable.
-///
-/// Create a one-dimensional read-only array view of the data in `slice`.
-///
-/// **Panics** if the slice length is greater than `isize::MAX`.
 impl<'a, A, Slice: ?Sized> From<&'a Slice> for ArrayView<'a, A, Ix1>
-    where Slice: AsRef<[A]>
+where
+    Slice: AsRef<[A]>,
 {
+    /// Create a one-dimensional read-only array view of the data in `slice`.
+    ///
+    /// **Panics** if the slice length is greater than `isize::MAX`.
     fn from(slice: &'a Slice) -> Self {
         let xs = slice.as_ref();
         if mem::size_of::<A>() == 0 {
@@ -230,32 +285,30 @@ impl<'a, A, Slice: ?Sized> From<&'a Slice> for ArrayView<'a, A, Ix1>
                 "Slice length must fit in `isize`.",
             );
         }
-        unsafe {
-            Self::from_shape_ptr(xs.len(), xs.as_ptr())
-        }
+        unsafe { Self::from_shape_ptr(xs.len(), xs.as_ptr()) }
     }
 }
 
 /// Implementation of `ArrayView::from(&A)` where `A` is an array.
-///
-/// Create a read-only array view of the array.
 impl<'a, A, S, D> From<&'a ArrayBase<S, D>> for ArrayView<'a, A, D>
-    where S: Data<Elem=A>,
-          D: Dimension,
+where
+    S: Data<Elem = A>,
+    D: Dimension,
 {
+    /// Create a read-only array view of the array.
     fn from(array: &'a ArrayBase<S, D>) -> Self {
         array.view()
     }
 }
 
 /// Implementation of `ArrayViewMut::from(&mut S)` where `S` is a slice or slicable.
-///
-/// Create a one-dimensional read-write array view of the data in `slice`.
-///
-/// **Panics** if the slice length is greater than `isize::MAX`.
 impl<'a, A, Slice: ?Sized> From<&'a mut Slice> for ArrayViewMut<'a, A, Ix1>
-    where Slice: AsMut<[A]>
+where
+    Slice: AsMut<[A]>,
 {
+    /// Create a one-dimensional read-write array view of the data in `slice`.
+    ///
+    /// **Panics** if the slice length is greater than `isize::MAX`.
     fn from(slice: &'a mut Slice) -> Self {
         let xs = slice.as_mut();
         if mem::size_of::<A>() == 0 {
@@ -264,19 +317,17 @@ impl<'a, A, Slice: ?Sized> From<&'a mut Slice> for ArrayViewMut<'a, A, Ix1>
                 "Slice length must fit in `isize`.",
             );
         }
-        unsafe {
-            Self::from_shape_ptr(xs.len(), xs.as_mut_ptr())
-        }
+        unsafe { Self::from_shape_ptr(xs.len(), xs.as_mut_ptr()) }
     }
 }
 
 /// Implementation of `ArrayViewMut::from(&mut A)` where `A` is an array.
-///
-/// Create a read-write array view of the array.
 impl<'a, A, S, D> From<&'a mut ArrayBase<S, D>> for ArrayViewMut<'a, A, D>
-    where S: DataMut<Elem=A>,
-          D: Dimension,
+where
+    S: DataMut<Elem = A>,
+    D: Dimension,
 {
+    /// Create a read-write array view of the array.
     fn from(array: &'a mut ArrayBase<S, D>) -> Self {
         array.view_mut()
     }
@@ -303,11 +354,17 @@ impl<'a, A, S, D> From<&'a mut ArrayBase<S, D>> for ArrayViewMut<'a, A, D>
 /// );
 ///
 /// ```
-pub trait AsArray<'a, A: 'a, D = Ix1> : Into<ArrayView<'a, A, D>> where D: Dimension { }
+pub trait AsArray<'a, A: 'a, D = Ix1>: Into<ArrayView<'a, A, D>>
+where
+    D: Dimension,
+{
+}
 impl<'a, A: 'a, D, T> AsArray<'a, A, D> for T
-    where T: Into<ArrayView<'a, A, D>>,
-          D: Dimension,
-{ }
+where
+    T: Into<ArrayView<'a, A, D>>,
+    D: Dimension,
+{
+}
 
 /// Create an owned array with a default state.
 ///
@@ -322,9 +379,10 @@ impl<'a, A: 'a, D, T> AsArray<'a, A, D> for T
 /// Since arrays cannot grow, the intention is to use the default value as
 /// placeholder.
 impl<A, S, D> Default for ArrayBase<S, D>
-    where S: DataOwned<Elem=A>,
-          D: Dimension,
-          A: Default,
+where
+    S: DataOwned<Elem = A>,
+    D: Dimension,
+    A: Default,
 {
     // NOTE: We can implement Default for non-zero dimensional array views by
     // using an empty slice, however we need a trait for nonzero Dimension.
