@@ -6,11 +6,11 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-use itertools::zip;
 use std::fmt;
 
 use super::Dimension;
 use super::IntoDimension;
+use crate::itertools::zip;
 use crate::Ix;
 
 /// Dimension description.
@@ -18,7 +18,7 @@ use crate::Ix;
 /// `Dim` describes the number of axes and the length of each axis
 /// in an array. It is also used as an index type.
 ///
-/// See also the [`Dimension` trait](Dimension.t.html) for its methods and
+/// See also the [`Dimension` trait](trait.Dimension.html) for its methods and
 /// operations.
 ///
 /// # Examples
