@@ -5,16 +5,17 @@
 // <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
-use imp_prelude::*;
-use DataClone;
 
-impl<S: DataClone, D: Clone> Clone for ArrayBase<S, D> {
+use crate::imp_prelude::*;
+use crate::RawDataClone;
+
+impl<S: RawDataClone, D: Clone> Clone for ArrayBase<S, D> {
     fn clone(&self) -> ArrayBase<S, D> {
         unsafe {
             let (data, ptr) = self.data.clone_with_ptr(self.ptr);
             ArrayBase {
-                data: data,
-                ptr: ptr,
+                data,
+                ptr,
                 dim: self.dim.clone(),
                 strides: self.strides.clone(),
             }
@@ -33,5 +34,4 @@ impl<S: DataClone, D: Clone> Clone for ArrayBase<S, D> {
     }
 }
 
-impl<S: DataClone + Copy, D: Copy> Copy for ArrayBase<S, D> {}
-
+impl<S: RawDataClone + Copy, D: Copy> Copy for ArrayBase<S, D> {}
