@@ -28,7 +28,7 @@ use crate::iter::{
     IndexedIter, IndexedIterMut, Iter, IterMut, Lanes, LanesMut, Windows,
 };
 use crate::slice::MultiSlice;
-use crate::stacking::stack;
+use crate::stacking::concatenate;
 use crate::{NdIndex, Slice, SliceInfo, SliceOrIndex};
 
 /// # Methods For All Array Types
@@ -456,15 +456,6 @@ where
             });
     }
 
-    /// Slice the array in place without changing the number of dimensions.
-    ///
-    /// **Panics** if an index is out of bounds or step size is zero.<br>
-    /// (**Panics** if `D` is `IxDyn` and `indices` does not match the number of array axes.)
-    #[deprecated(note = "renamed to `slice_collapse`", since = "0.12.1")]
-    pub fn slice_inplace(&mut self, indices: &D::SliceArg) {
-        self.slice_collapse(indices)
-    }
-
     /// Return a view of the array, sliced along the specified axis.
     ///
     /// **Panics** if an index is out of bounds or step size is zero.<br>
@@ -759,51 +750,6 @@ where
         debug_assert!(self.pointer_is_inbounds());
     }
 
-    /// Along `axis`, select the subview `index` and return a
-    /// view with that axis removed.
-    ///
-    /// **Panics** if `axis` or `index` is out of bounds.
-    #[deprecated(note = "renamed to `index_axis`", since = "0.12.1")]
-    pub fn subview(&self, axis: Axis, index: Ix) -> ArrayView<'_, A, D::Smaller>
-    where
-        S: Data,
-        D: RemoveAxis,
-    {
-        self.index_axis(axis, index)
-    }
-
-    /// Along `axis`, select the subview `index` and return a read-write view
-    /// with the axis removed.
-    ///
-    /// **Panics** if `axis` or `index` is out of bounds.
-    #[deprecated(note = "renamed to `index_axis_mut`", since = "0.12.1")]
-    pub fn subview_mut(&mut self, axis: Axis, index: Ix) -> ArrayViewMut<'_, A, D::Smaller>
-    where
-        S: DataMut,
-        D: RemoveAxis,
-    {
-        self.index_axis_mut(axis, index)
-    }
-
-    /// Collapse dimension `axis` into length one,
-    /// and select the subview of `index` along that axis.
-    ///
-    /// **Panics** if `index` is past the length of the axis.
-    #[deprecated(note = "renamed to `collapse_axis`", since = "0.12.1")]
-    pub fn subview_inplace(&mut self, axis: Axis, index: Ix) {
-        self.collapse_axis(axis, index)
-    }
-
-    /// Along `axis`, select the subview `index` and return `self`
-    /// with that axis removed.
-    #[deprecated(note = "renamed to `index_axis_move`", since = "0.12.1")]
-    pub fn into_subview(self, axis: Axis, index: Ix) -> ArrayBase<S, D::Smaller>
-    where
-        D: RemoveAxis,
-    {
-        self.index_axis_move(axis, index)
-    }
-
     /// Along `axis`, select arbitrary subviews corresponding to `indices`
     /// and and copy them into a new array.
     ///
@@ -840,7 +786,7 @@ where
             dim.set_axis(axis, 0);
             unsafe { Array::from_shape_vec_unchecked(dim, vec![]) }
         } else {
-            stack(axis, &subs).unwrap()
+            concatenate(axis, &subs).unwrap()
         }
     }
 
@@ -1293,7 +1239,11 @@ where
         is_standard_layout(&self.dim, &self.strides)
     }
 
-    fn is_contiguous(&self) -> bool {
+    /// Return true if the array is known to be contiguous.
+    ///
+    /// Will detect c- and f-contig arrays correctly, but otherwise
+    /// There are some false negatives.
+    pub(crate) fn is_contiguous(&self) -> bool {
         D::is_contiguous(&self.dim, &self.strides)
     }
 
@@ -1359,7 +1309,7 @@ where
     where
         S: RawDataMut,
     {
-        self.try_ensure_unique(); // for RcArray
+        self.try_ensure_unique(); // for ArcArray
         self.ptr.as_ptr()
     }
 
@@ -1375,7 +1325,7 @@ where
     where
         S: RawDataMut,
     {
-        self.try_ensure_unique(); // for RcArray
+        self.try_ensure_unique(); // for ArcArray
         unsafe { RawArrayViewMut::new(self.ptr, self.dim.clone(), self.strides.clone()) }
     }
 
@@ -1882,8 +1832,10 @@ where
 
     /// Remove array axis `axis` and return the result.
     ///
+    /// This is equivalent to `.index-axis_move(axis, 0)` and makes most sense to use if the
+    /// axis to remove is of length 1.
+    ///
     /// **Panics** if the axis is out of bounds or its length is zero.
-    #[deprecated(note = "use `.index_axis_move(Axis(_), 0)` instead", since = "0.12.1")]
     pub fn remove_axis(self, axis: Axis) -> ArrayBase<S, D::Smaller>
     where
         D: RemoveAxis,
