@@ -6,12 +6,11 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 #![crate_name = "ndarray"]
-#![doc(html_root_url = "https://docs.rs/ndarray/0.13/")]
+#![doc(html_root_url = "https://docs.rs/ndarray/0.14/")]
 #![allow(
     clippy::many_single_char_names,
     clippy::deref_addrof,
     clippy::unreadable_literal,
-    clippy::many_single_char_names
 )]
 
 //! The `ndarray` crate provides an *n*-dimensional container for general elements
@@ -53,15 +52,16 @@
 //! - Performance:
 //!   + Prefer higher order methods and arithmetic operations on arrays first,
 //!     then iteration, and as a last priority using indexed algorithms.
-//!   + The higher order functions like ``.map()``, ``.map_inplace()``,
-//!     ``.zip_mut_with()``, ``Zip`` and ``azip!()`` are the most efficient ways
+//!   + The higher order functions like [`.map()`](ArrayBase::map),
+//!     [`.map_inplace()`](ArrayBase::map_inplace), [`.zip_mut_with()`](ArrayBase::zip_mut_with),
+//!     [`Zip`] and [`azip!()`](azip) are the most efficient ways
 //!     to perform single traversal and lock step traversal respectively.
 //!   + Performance of an operation depends on the memory layout of the array
 //!     or array view. Especially if it's a binary operation, which
 //!     needs matching memory layout to be efficient (with some exceptions).
 //!   + Efficient floating point matrix multiplication even for very large
 //!     matrices; can optionally use BLAS to improve it further.
-//! - **Requires Rust 1.37 or later**
+//! - **Requires Rust 1.42 or later**
 //!
 //! ## Crate Feature Flags
 //!
@@ -105,6 +105,9 @@
 //! but more advanced routines can be found in [`ndarray-stats`](https://crates.io/crates/ndarray-stats).
 //!
 //! If you are looking to generate random arrays instead, check out [`ndarray-rand`](https://crates.io/crates/ndarray-rand).
+//!
+//! For conversion between `ndarray`, [`nalgebra`](https://crates.io/crates/nalgebra) and 
+//! [`image`](https://crates.io/crates/image) check out [`nshare`](https://crates.io/crates/nshare).
 
 #[cfg(feature = "blas")]
 extern crate blas_src;
@@ -131,7 +134,8 @@ use crate::iterators::{ElementsBase, ElementsBaseMut, Iter, IterMut, Lanes, Lane
 
 pub use crate::arraytraits::AsArray;
 pub use crate::linalg_traits::{LinalgScalar, NdFloat};
-pub use crate::stacking::stack;
+
+pub use crate::stacking::{concatenate, stack, stack_new_axis};
 
 pub use crate::impl_views::IndexLonger;
 pub use crate::shape_builder::ShapeBuilder;
@@ -176,9 +180,11 @@ mod linalg_traits;
 mod linspace;
 mod logspace;
 mod numeric_util;
+mod partial;
 mod shape_builder;
 #[macro_use]
 mod slice;
+mod split_at;
 mod stacking;
 #[macro_use]
 mod zip;
@@ -300,9 +306,10 @@ pub type Ixs = isize;
 /// Please see the documentation for the respective array view for an overview
 /// of methods specific to array views: [`ArrayView`], [`ArrayViewMut`].
 ///
-/// A view is created from an array using `.view()`, `.view_mut()`, using
-/// slicing (`.slice()`, `.slice_mut()`) or from one of the many iterators
-/// that yield array views.
+/// A view is created from an array using [`.view()`](ArrayBase::view),
+/// [`.view_mut()`](ArrayBase::view_mut), using
+/// slicing ([`.slice()`](ArrayBase::slice), [`.slice_mut()`](ArrayBase::slice_mut)) or from one of
+/// the many iterators that yield array views.
 ///
 /// You can also create an array view from a regular slice of data not
 /// allocated with `Array` — see array view methods or their `From` impls.
@@ -1234,14 +1241,6 @@ where
     strides: D,
 }
 
-/// An array where the data has shared ownership and is copy on write.
-///
-/// It can act as both an owner as the data as well as a shared reference (view like).
-///
-/// **Note: this type alias is obsolete.** See the equivalent [`ArcArray`] instead.
-#[deprecated(note = "`RcArray` has been renamed to `ArcArray`")]
-pub type RcArray<A, D> = ArrayBase<OwnedRcRepr<A>, D>;
-
 /// An array where the data has shared ownership and is copy on write.
 ///
 /// The `ArcArray<A, D>` is parameterized by `A` for the element type and `D` for
@@ -1392,14 +1391,6 @@ pub type RawArrayViewMut<A, D> = ArrayBase<RawViewRepr<*mut A>, D>;
 
 pub use data_repr::OwnedRepr;
 
-
-/// RcArray's representation.
-///
-/// *Don’t use this type directly—use the type alias
-/// [`RcArray`](type.RcArray.html) for the array type!*
-#[deprecated(note = "RcArray is replaced by ArcArray")]
-pub use self::OwnedArcRepr as OwnedRcRepr;
-
 /// ArcArray's representation.
 ///
 /// *Don’t use this type directly—use the type alias
