@@ -10,11 +10,11 @@
 //! The following types implement parallel iterators, accessed using these
 //! methods:
 //!
-//! - [`Array`], [`ArcArray`]: `.par_iter()` and `.par_iter_mut()`
-//! - [`ArrayView`](ArrayView): `.into_par_iter()`
-//! - [`ArrayViewMut`](ArrayViewMut): `.into_par_iter()`
-//! - [`AxisIter`](iter::AxisIter), [`AxisIterMut`](iter::AxisIterMut): `.into_par_iter()`
-//! - [`AxisChunksIter`](iter::AxisChunksIter), [`AxisChunksIterMut`](iter::AxisChunksIterMut): `.into_par_iter()`
+//! - [`Array`], [`ArcArray`] `.par_iter()` and `.par_iter_mut()`
+//! - [`ArrayView`] `.into_par_iter()`
+//! - [`ArrayViewMut`] `.into_par_iter()`
+//! - [`AxisIter`], [`AxisIterMut`] `.into_par_iter()`
+//! - [`AxisChunksIter`], [`AxisChunksIterMut`] `.into_par_iter()`
 //! - [`Zip`] `.into_par_iter()`
 //!
 //! The following other parallelized methods exist:
@@ -39,8 +39,6 @@
 //! Compute the exponential of each element in an array, parallelized.
 //!
 //! ```
-//! extern crate ndarray;
-//!
 //! use ndarray::Array2;
 //! use ndarray::parallel::prelude::*;
 //!
@@ -61,8 +59,6 @@
 //! Use the parallel `.axis_iter()` to compute the sum of each row.
 //!
 //! ```
-//! extern crate ndarray;
-//!
 //! use ndarray::Array;
 //! use ndarray::Axis;
 //! use ndarray::parallel::prelude::*;
@@ -84,8 +80,6 @@
 //! Use the parallel `.axis_chunks_iter()` to process your data in chunks.
 //!
 //! ```
-//! extern crate ndarray;
-//!
 //! use ndarray::Array;
 //! use ndarray::Axis;
 //! use ndarray::parallel::prelude::*;
@@ -107,8 +101,6 @@
 //! Use zip for lock step function application across several arrays
 //!
 //! ```
-//! extern crate ndarray;
-//!
 //! use ndarray::Array3;
 //! use ndarray::Zip;
 //!
@@ -129,6 +121,23 @@
 //! }
 //! ```
 
+#[allow(unused_imports)] // used by rustdoc links
+use crate::{
+    ArrayBase,
+    Array,
+    ArcArray,
+    ArrayView,
+    ArrayViewMut,
+    Zip,
+};
+#[allow(unused_imports)] // used by rustdoc links
+use crate::iter::{
+    AxisIter,
+    AxisIterMut,
+    AxisChunksIter,
+    AxisChunksIterMut,
+};
+
 /// Into- traits for creating parallelized iterators and/or using [`par_azip!`]
 pub mod prelude {
     #[doc(no_inline)]
@@ -146,4 +155,5 @@ pub use crate::par_azip;
 mod impl_par_methods;
 mod into_impls;
 mod par;
+mod send_producer;
 mod zipmacro;
