@@ -110,18 +110,12 @@ copy_and_clone! {SliceOrIndex}
 impl SliceOrIndex {
     /// Returns `true` if `self` is a `Slice` value.
     pub fn is_slice(&self) -> bool {
-        match self {
-            SliceOrIndex::Slice { .. } => true,
-            _ => false,
-        }
+        matches!(self, SliceOrIndex::Slice { .. })
     }
 
     /// Returns `true` if `self` is an `Index` value.
     pub fn is_index(&self) -> bool {
-        match self {
-            SliceOrIndex::Index(_) => true,
-            _ => false,
-        }
+        matches!(self, SliceOrIndex::Index(_))
     }
 
     /// Returns a new `SliceOrIndex` with the given step size (multiplied with
@@ -496,8 +490,6 @@ impl_slicenextdim_larger!((), Slice);
 /// # Example
 ///
 /// ```
-/// extern crate ndarray;
-///
 /// use ndarray::{s, Array2, ArrayView2};
 ///
 /// fn laplacian(v: &ArrayView2<f32>) -> Array2<f32> {
@@ -528,8 +520,6 @@ impl_slicenextdim_larger!((), Slice);
 /// For example,
 ///
 /// ```
-/// # extern crate ndarray;
-/// #
 /// # use ndarray::prelude::*;
 /// #
 /// # fn main() {
